# coding: utf-8

"""
    ARLAS permissions API

    permissions REST services

    OpenAPI spec version: 19.0.0
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into sdk package
from .models.error import Error
from .models.resource import Resource

# import apis into sdk package
from .apis.authorize_api import AuthorizeApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()
