# coding: utf-8

"""
    ARLAS permissions API

    permissions REST services

    OpenAPI spec version: 19.0.0
    Contact: contact@gisaia.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import arlas_permissions_api_python
from arlas_permissions_api_python.rest import ApiException
from arlas_permissions_api_python.apis.authorize_api import AuthorizeApi


class TestAuthorizeApi(unittest.TestCase):
    """ AuthorizeApi unit test stubs """

    def setUp(self):
        self.api = arlas_permissions_api_python.apis.authorize_api.AuthorizeApi()

    def tearDown(self):
        pass

    def test_get(self):
        """
        Test case for get

        Returns a list of permissions for the current context/user
        """
        pass


if __name__ == '__main__':
    unittest.main()
